==> iisp-ts-common-4.2.1.tgz: package/src/base.sub.component.ts <==
import { Response } from '@angular/http';
import { ViewChild } from '@angular/core';
import { MessageService } from 'primeng/api';
import { Utils } from './utils';
import { MessageBoxComponent } from './messagebox.component';

declare var calLang: any, fileDownloadRoot: string, isRunning: number;
export abstract class BaseSubComponent {
	calLang = calLang;
	constructor(private messageService: MessageService ) { }
	/**
	 * 解析国际化消息
	 * @param key 键
	 * @param params 参数
	 */
	resolveMessage(key: string, ...params: string[]): string {
		return Utils.resolveLocalizedMessage(key, params);
	}
	/**
	 * 生成下载链接。
	 * @param uri 附件的相对路径
	 */
	resolveDownloadUrl(uri: string): string {
		return fileDownloadRoot + encodeURI(uri);
	}
	/**
	 * 处理错误
	 * @param error 错误对象
	 */
	protected handleError(error: any): void {
			this.showMessage(error, "error");
	}
	/**
	 * 显示错误消息
	 * @param message 消息
	 */
	protected showError(message: string) {
		this.showMessage(message, "error");
	}
	/**
	 * i18n的显示警告消息
	 * @param messageKey 要显示的消息key
	 */
	protected showWarnKey(messageKey: string) {
		this.showMessage(this.resolveMessage(messageKey), "warn");
	}
	/**
	 * i18n的显示成功消息
	 * @param messageKey 要显示的消息key
	 */
	protected showSuccessKey(messageKey: string) {
		this.showMessage(this.resolveMessage(messageKey), "success");
	}
	/**
	 * 	i18n的显示通知消息
	 * @param messageKey 要显示的消息key
	 */
	protected showInfoKey(messageKey: string) {
		this.showMessage(this.resolveMessage(messageKey), "info");
	}
	/**
	 * 	i18n的显示错误消息
	 * @param messageKey 要显示的消息key
	 */
	protected showErrorKey(messageKey: string) {
		this.showMessage(this.resolveMessage(messageKey), "error");
	}
	/**
	 * 显示消息
	 * @param message 要显示的消息
	 * @param style 消息风格，"warn","success","info","error"
	 */
	protected showMessage(message: string,style?: string): void {
	    if (!style) {
	        style = "info"
	    }
        let title = Utils.resolveLocalizedMessage("msg." + style);
        this.messageService.add({life:MessageBoxComponent.lifeTimeMap[style]*1000, severity: style, summary: title, detail: message });
    }

	/**
	 * 获取请求串中的参数值
	 * @param name 参数名称
	 * 
	 */
	protected getRequestParamValue(name: string): string {
		let result = location.search.match(new RegExp("[\?\&]" + name + "=([^\&]+)", "i"));
		if (result == null || result.length < 1) {
			return null;
		}
		return result[1];
	}
	/**
	 * 获取请求串中的参数值数组，如a=x&a=y, 则参数a的值为['x','y']
	 * @param name 参数名称
	 */
	protected getRequestParamValues(name: string): string[] {
		let result = location.search.match(new RegExp("[\?\&]" + name + "=([^\&]+)", "i"));
		if (result == null || result.length < 1) {
			return null;
		}
		return result;
	}
	
	/**
	 * 判断是否有异步任务正在执行，以便界面显示相关信息，让用户等待
	 */
	isRunning(): boolean {
		return isRunning > 0;
	}
}

==> iisp-ts-common-7.2.7.tgz: package/src/base.sub.component.ts <==
import { Response } from '@angular/http';
import { ViewChild } from '@angular/core';
import { MessageService } from 'primeng/api';
import { Utils } from './utils';

declare var calLang: any;
export abstract class BaseSubComponent {
	calLang = calLang;
	constructor(private messageService: MessageService ) { }
	/**
	 * 解析国际化消息
	 * @param key 键
	 * @param params 参数
	 */
	resolveMessage(key: string, ...params: string[]): string {
		return Utils.resolveLocalizedMessage(key, params);
	}
    /**
     *  把代码映射成字典表中的i18n值，如果代码为空，则返回代码为defaultKey的值，如果连defaultKey也找不到值，则返回代码本身，如果 代码为null或undefined则返回空串。
     * @param key 要映射的代码,或是RefBean
     * @param dictMap 字典数据
     * @param defaultKey 缺省代码，可选参数，缺省为"-"
     */
    lookup(key: any, dictMap: Object, defaultKey = "-"):string{
        return Utils.lookup(key, dictMap, defaultKey);
    }
	/**
	 * 处理错误
	 * @param error 错误对象
	 */
	protected handleError(error: any): void {
			this.showMessage(error, "error");
	}
	/**
	 * 显示错误消息
	 * @param message 消息
	 */
	protected showError(message: string) {
		this.showMessage(message, "error");
	}
	/**
	 * i18n的显示警告消息
	 * @param messageKey 要显示的消息key
	 */
	protected showWarnKey(messageKey: string) {
		this.showMessage(this.resolveMessage(messageKey), "warn");
	}
	/**
	 * i18n的显示成功消息
	 * @param messageKey 要显示的消息key
	 */
	protected showSuccessKey(messageKey: string) {
		this.showMessage(this.resolveMessage(messageKey), "success");
	}
	/**
	 * 	i18n的显示通知消息
	 * @param messageKey 要显示的消息key
	 */
	protected showInfoKey(messageKey: string) {
		this.showMessage(this.resolveMessage(messageKey), "info");
	}
	/**
	 * 	i18n的显示错误消息
	 * @param messageKey 要显示的消息key
	 */
	protected showErrorKey(messageKey: string) {
		this.showMessage(this.resolveMessage(messageKey), "error");
	}
	/**
	 * 显示消息
	 * @param message 要显示的消息
	 * @param style 消息风格，"warn","success","info","error"
	 */
	protected showMessage(message: string,style?: string): void {
	    if (!style) {
	        style = "info"
	    }
        let title = Utils.resolveLocalizedMessage("msg.type." + style);
        this.messageService.add({severity:style, summary:title, detail:message});
    }

	/**
	 * 获取请求串中的参数值
	 * @param name 参数名称
	 * 
	 */
	protected getRequestParamValue(name: string): string {
		let result = location.search.match(new RegExp("[\?\&]" + name + "=([^\&]+)", "i"));
		if (result == null || result.length < 1) {
			return null;
		}
		return result[1];
	}
	/**
	 * 获取请求串中的参数值数组，如a=x&a=y, 则参数a的值为['x','y']
	 * @param name 参数名称
	 */
	protected getRequestParamValues(name: string): string[] {
		let result = location.search.match(new RegExp("[\?\&]" + name + "=([^\&]+)", "i"));
		if (result == null || result.length < 1) {
			return null;
		}
		return result;
	}
}
